@@ -17,7 +17,8 @@ def test_import_globals_without_inspection():
     locals_ = {}
     globals_ = {'__name__': __name__}
     import_.import_global(
-        'python_utils.formatters', locals_=locals_, globals_=globals_)
+        'python_utils.formatters', locals_=locals_, globals_=globals_
+    )
     assert 'camel_to_underscore' in globals_
 
 
@@ -25,8 +26,11 @@ def test_import_globals_single_method():
     locals_ = {}
     globals_ = {'__name__': __name__}
     import_.import_global(
-        'python_utils.formatters', ['camel_to_underscore'], locals_=locals_,
-        globals_=globals_)
+        'python_utils.formatters',
+        ['camel_to_underscore'],
+        locals_=locals_,
+        globals_=globals_,
+    )
     assert 'camel_to_underscore' in globals_
 
 
@@ -37,12 +41,13 @@ def test_import_globals_with_inspection():
 
 def test_import_globals_missing_module():
     import_.import_global(
-        'python_utils.spam', exceptions=ImportError, locals_=locals())
+        'python_utils.spam', exceptions=ImportError, locals_=locals()
+    )
     assert 'camel_to_underscore' in globals()
 
 
 def test_import_locals_missing_module():
     import_.import_global(
-        'python_utils.spam', exceptions=ImportError, globals_=globals())
+        'python_utils.spam', exceptions=ImportError, globals_=globals()
+    )
     assert 'camel_to_underscore' in globals()
-
