@@ -1,16 +1,24 @@
 import datetime
 import decimal
-from typing import *  # pragma: no cover
+import sys
+from typing import *  # type: ignore # pragma: no cover
+
 # import * does not import Pattern
 from typing import Pattern
 
+if sys.version_info >= (3, 8):  # pragma: no cover
+    from typing import Literal, SupportsIndex
+else:  # pragma: no cover
+    from typing_extensions import Literal, SupportsIndex
+
 # Quickhand for optional because it gets so much use. If only Python had
 # support for an optional type shorthand such as `SomeType?` instead of
 # `Optional[SomeType]`.
-from typing import Optional as O
+from typing import Optional as O  # noqa
+
 # Since the Union operator is only supported for Python 3.10, we'll create a
 # shorthand for it.
-from typing import Union as U
+from typing import Union as U  # noqa
 
 Scope = Dict[str, Any]
 OptionalScope = O[Scope]
@@ -31,7 +39,9 @@ timestamp_type = U[
     None,
 ]
 
-assert Pattern
+assert Pattern is not None  # type: ignore
+assert Literal is not None
+assert SupportsIndex is not None
 
 __all__ = [
     'OptionalScope',
@@ -39,9 +49,7 @@ __all__ = [
     'DecimalNumber',
     'delta_type',
     'timestamp_type',
-
     # The types from the typing module.
-
     # Super-special typing primitives.
     'Annotated',
     'Any',
@@ -52,6 +60,7 @@ __all__ = [
     'ForwardRef',
     'Generic',
     'Literal',
+    'SupportsIndex',
     'Optional',
     'ParamSpec',
     'Protocol',
@@ -59,7 +68,6 @@ __all__ = [
     'Type',
     'TypeVar',
     'Union',
-
     # ABCs (from collections.abc).
     'AbstractSet',  # collections.abc.Set.
     'ByteString',
@@ -85,7 +93,6 @@ __all__ = [
     'Collection',
     'AsyncGenerator',
     'AsyncContextManager',
-
     # Structural checks, a.k.a. protocols.
     'Reversible',
     'SupportsAbs',
@@ -95,7 +102,6 @@ __all__ = [
     'SupportsIndex',
     'SupportsInt',
     'SupportsRound',
-
     # Concrete collection types.
     'ChainMap',
     'Counter',
@@ -109,14 +115,12 @@ __all__ = [
     'NamedTuple',  # Not really a type.
     'TypedDict',  # Not really a type.
     'Generator',
-
     # Other concrete types.
     'BinaryIO',
     'IO',
     'Match',
     'Pattern',
     'TextIO',
-
     # One-off things.
     'AnyStr',
     'cast',
@@ -137,4 +141,5 @@ __all__ = [
     'TYPE_CHECKING',
     'TypeAlias',
     'TypeGuard',
+    'TracebackType',
 ]
